@@ -13,7 +13,7 @@ use Class::Accessor::Lite::Lazy (
 
 use WebService::Slack::WebApi::Client;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub _build_client {
     my $self = shift;
@@ -56,7 +56,7 @@ WebService::Slack::WebApi - a simple wrapper for Slack Web API
     # posting message to specified channel and getting message description
     my $posted_message = $slack->chat->post_message(
         channel  => 'channel id', # required
-        text     => 'hoge',       # required
+        text     => 'hoge',       # required (not required if 'attachments' argument exists)
         username => 'fuga',       # optional
         # othre optional parameters...
     );
